@@ -9,9 +9,9 @@ class RequestFormatter(logging.Formatter):
 
         :param kwargs:
         """
-        self.app_name = flask.current_app.config['LOG_APP_NAME']
-        req_id_header = kwargs.pop('request_id_header', None) or 'X-Request-ID'
-        req_id_header = req_id_header.upper().replace('-', '_')
+        self.app_name = flask.current_app.config["LOG_APP_NAME"]
+        req_id_header = kwargs.pop("request_id_header", None) or "X-Request-ID"
+        req_id_header = req_id_header.upper().replace("-", "_")
         self.request_id_header = f"HTTP_{req_id_header}"
         super().__init__(*args, **kwargs)
 
