@@ -33,17 +33,17 @@ class FlaskLogging:
         :param app: Flask app instance
         :param builder:
         """
-        if not hasattr(app, 'extensions'):
-            app.extensions = dict()
-        app.extensions['logify'] = self
+        if not hasattr(app, "extensions"):
+            app.extensions = {}
+        app.extensions["logify"] = self
 
         self.set_default_config(app)
         self.set_request_id(app)
 
-        if app.config['LOG_BUILDER']:
-            builder = builder_factory(app.config['LOG_BUILDER'])
+        if app.config["LOG_BUILDER"]:
+            builder = builder_factory(app.config["LOG_BUILDER"])
 
-        if type(builder) is str:
+        if isinstance(builder, str):
             builder = builder_factory(builder)
 
         if builder:
@@ -51,26 +51,30 @@ class FlaskLogging:
             app.before_request_funcs.setdefault(None, []).append(builder.dump_request)
             app.after_request_funcs.setdefault(None, []).append(builder.dump_response)
 
-        if app.config['LOG_FILE_CONF']:
+        if app.config["LOG_FILE_CONF"]:
             try:
-                with open(app.config['LOG_FILE_CONF']) as f:
+                with open(app.config["LOG_FILE_CONF"], encoding="utf-8") as f:
                     self._conf = yaml.safe_load(f)
             except (OSError, IOError, yaml.YAMLError) as exc:
                 app.logger.exception(exc, stack_info=False)
 
-        if not self._conf and app.config['LOGGING']:
-            self._conf = app.config['LOGGING']
+        if not self._conf and app.config["LOGGING"]:
+            self._conf = app.config["LOGGING"]
 
         if self._conf:
             try:
                 logging.config.dictConfig(self._conf)
-                app.logger = logging.getLogger(app.config['LOG_LOGGER_NAME'])
+                app.logger = logging.getLogger(app.config["LOG_LOGGER_NAME"])
             except ValueError as exc:
-                app.logger.error("bad configuration file: %s", app.config['LOG_FILE_CONF'])
+                app.logger.error(
+                    "bad configuration file: %s", app.config["LOG_FILE_CONF"]
+                )
                 app.logger.error("the configuration below\n", self._conf)
                 app.logger.exception(exc, stack_info=False)
         else:
-            app.logger.warning("No logging configuration provided using default configuration")
+            app.logger.warning(
+                "No logging configuration provided using default configuration"
+            )
 
     @staticmethod
     def set_request_id(app):
@@ -82,7 +86,7 @@ class FlaskLogging:
 
         @app.before_request
         def req_id():
-            h = flask.current_app.config['REQUEST_ID_HEADER']
+            h = flask.current_app.config["REQUEST_ID_HEADER"]
             header = f"HTTP_{h.upper().replace('-', '_')}"
             flask.g.request_id = flask.request.environ.get(header)
 
@@ -107,7 +111,7 @@ class FlaskLogging:
 
         def response(fun):
             for log in loggers:
-                logger = logging.getLogger(log or '')
+                logger = logging.getLogger(log or "")
                 logger.addFilter(filter_class(**options))
 
             @wraps(fun)
@@ -124,25 +128,25 @@ class FlaskLogging:
 
         param app: Flask app instance
         """
-        app.config.setdefault('LOGGING', None)
-        app.config.setdefault('LOG_FILE_CONF', None)
-        app.config.setdefault('LOG_BUILDER', 'text')
-        app.config.setdefault('REQUEST_ID_HEADER', 'X-Request-ID')
+        app.config.setdefault("LOGGING", None)
+        app.config.setdefault("LOG_FILE_CONF", None)
+        app.config.setdefault("LOG_BUILDER", "text")
+        app.config.setdefault("REQUEST_ID_HEADER", "X-Request-ID")
 
-        app.config.setdefault('LOG_REQ_SKIP_DUMP', not app.debug)
-        app.config.setdefault('LOG_REQ_HEADERS', [])
+        app.config.setdefault("LOG_REQ_SKIP_DUMP", not app.debug)
+        app.config.setdefault("LOG_REQ_HEADERS", [])
         app.config.setdefault(
-            'LOG_REQ_FORMAT',
-            "INCOMING REQUEST: {address} {method} {scheme} {path}{headers}{body}"
+            "LOG_REQ_FORMAT",
+            "INCOMING REQUEST: {address} {method} {scheme} {path}{headers}{body}",
         )
 
-        app.config.setdefault('LOG_RESP_SKIP_DUMP', app.debug)
-        app.config.setdefault('LOG_RESP_HEADERS', [])
+        app.config.setdefault("LOG_RESP_SKIP_DUMP", app.debug)
+        app.config.setdefault("LOG_RESP_HEADERS", [])
         app.config.setdefault(
-            'LOG_RESP_FORMAT',
-            "OUTGOING RESPONSE for {address} at {path}: {level} STATUS {status}{headers}{body}"
+            "LOG_RESP_FORMAT",
+            "OUTGOING RESPONSE for {address} at {path}: {level} STATUS {status}{headers}{body}",
         )
 
-        env = app.config.get('FLASK_ENV') or 'development'
-        app.config.setdefault('LOG_APP_NAME', app.config.get('APP_NAME') or 'flask')
-        app.config.setdefault('LOG_LOGGER_NAME', f"{env}")
+        env = app.config.get("FLASK_ENV") or "development"
+        app.config.setdefault("LOG_APP_NAME", app.config.get("APP_NAME") or "flask")
+        app.config.setdefault("LOG_LOGGER_NAME", f"{env}")
